@@ -9,11 +9,11 @@ import pulumi_azure_native.network as network
 # vdc.suffix = props.suffix
 # vdc.tags = props.tags
 
-def virtual_network(stem, address_spaces, depends_on=None,):
+def virtual_network(stem,props, address_spaces, depends_on=None,):
     vn = network.VirtualNetwork(
         f'vn-{stem}',
         virtual_network_name=f'vn-{stem}',
-        resource_group_name=resource_group_name,
+        resource_group_name=props.resource_group_name,
         address_space=network.AddressSpaceArgs(
             address_prefixes=address_spaces,
         ),
@@ -25,6 +25,7 @@ def virtual_network(stem, address_spaces, depends_on=None,):
 
 def vnet_peering(
         stem,
+        props,
         rg,
         virtual_network_name,
         peer,
@@ -38,7 +39,7 @@ def vnet_peering(
         f'vnpr-{stem}',
         name=f'vnpr-{stem}',
         resource_group_name=rg,
-        virtual_network_name=virtual_network_name,
+        virtual_network_name=props.virtual_network_name,
         remote_virtual_network=network.SubResourceArgs(
             id=remote_virtual_network_id
         ),
@@ -53,6 +54,7 @@ def vnet_peering(
 
 def subnet(
         stem,
+        props,
         virtual_network_name,
         address_prefix,
         route_table_id,
@@ -61,7 +63,7 @@ def subnet(
     sn = network.Subnet(
         f'sn-{stem}',
         name=f'sn-{stem}',
-        resource_group_name=resource_group_name,
+        resource_group_name=props.resource_group_name,
         virtual_network_name=virtual_network_name,
         address_prefix=address_prefix,
         route_table=network.RouteTableArgs(
@@ -73,6 +75,7 @@ def subnet(
 
 def subnet_special(
         stem,
+        props,
         name,
         virtual_network_name,
         address_prefix,
@@ -83,7 +86,7 @@ def subnet_special(
         f'sn-{stem}',
         name=name,
         subnet_name=name,
-        resource_group_name=resource_group_name,
+        resource_group_name=props.resource_group_name,
         virtual_network_name=virtual_network_name,
         address_prefix=address_prefix,
         route_table=network.RouteTableArgs(
